==> question2answer-1.5-language-pt-BR.zip: pt/qa-lang-users.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-users.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user management


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'about' => 'Sobre',
		'add_user_x_favorites' => 'Adicionar usuário ^ aos meus favoritos',
		'avatar_default' => 'Padrão',
		'avatar_gravatar' => 'Mostrar meu ^1Gravatar^2',
		'avatar_label' => 'Avatar:',
		'avatar_none' => 'Nenhum',
		'block_user_button' => 'Bloquear usuário',
		'blocked_users' => 'Usuários bloqueados',
		'change_email_link' => ' - ^1mudar email^2',
		'change_password' => 'Alterar Senha',
		'confirm_complete' => 'Obrigado - Seu email foi confirmado',
		'confirm_emailed' => 'Um link de confirmação foi enviado a seu email. Clique nele para confirmá-lo.',
		'confirm_required' => 'Para completar o cadastro, clique no link de confirmação enviado a seu email ou ^1peça outro^2.',
		'confirm_title' => 'Confirmação de Email',
		'confirm_wrong_log_in' => 'Código Incorreto - ^1entre^2 para receber outro link',
		'confirm_wrong_resend' => 'Código Incorreto - clique abaixo para enviar novamente',
		'delete_user_button' => 'Excluir Usuário',
		'edit_user_button' => 'Editar Usuário',
		'email_confirmed' => 'Confirmado',
		'email_exists' => 'Email já pertence a outra conta',
		'email_handle_label' => 'Email or Nome:',
		'email_invalid' => 'Email é inválido - confira com cuidado',
		'email_label' => 'Email:',
		'email_not_confirmed' => 'Ainda não confirmado',
		'email_please_confirm' => '^5Confirme^6',
		'email_required' => 'Email necessário - não público',
		'forgot_link' => 'Esqueci minha senha',
		'full_name' => 'Nome completo',
		'handle_empty' => 'Nome não pode ficar vazio',
		'handle_exists' => 'Nome está em uso - tente outro',
		'handle_has_bad' => 'Nome não pode conter: ^',
		'handle_label' => 'Nome:',
		'hide_all_user_button' => 'Ocultar todas as publicações desse usuário',
		'last_login_label' => 'Última visita:',
		'last_write_label' => 'Última publicação:',
		'level_admin' => 'Administrador',
		'level_editor' => 'Editor',
		'level_expert' => 'Expert',
		'level_moderator' => 'Moderador',
		'level_super' => 'Super Administrador',
		'location' => 'Localização',
		'log_in_to_access' => 'Você pode ^1acessar^2 a sua conta.',
		'login_button' => 'Login',
		'login_limit' => 'Muitas tentativas de login - tente novamente em uma hora',
		'login_title' => 'Login',
		'mass_mailings_explanation' => 'Inscreva-se nos email enviados a todos os usuários',
		'mass_mailings' => 'Emails em massa:',
		'member_for' => 'Usuário por:',
		'member_type' => 'Tipo:',
		'new_password_1' => 'Nova senha:',
		'new_password_2' => 'Redigite a nova senha:',
		'no_blocked_users' => 'Nenhum usuário bloqueado encontrado',
		'no_permission' => 'Você não permissão para executar essa operação',
		'old_password' => 'Senha antiga:',
		'only_shown_admins' => '(somente mostrado a administradores)',
		'only_shown_moderators' => '(somente mostrado a moderadores)',
		'password_changed' => 'Senha alterada',
		'password_label' => 'Senha:',
		'password_min' => 'Senha deve ter ao menos ^ caracteres',
		'password_mismatch' => 'As senhas não conferem',
		'password_none' => 'Nenhum. Para fazer login diretamente, escolha uma senha abaixo.',
		'password_sent' => 'Sua nova senha foi enviada a seu email',
		'password_to_set' => 'Defina na página da sua conta',
		'password_wrong' => 'Senha incorreta',
		'private_messages_explanation' => 'Permitir que usuários me enviem emails (sem mostrar meu email)',
		'private_messages' => 'Mensagens privadas:',
		'profile_saved' => 'Perfil salvo',
		'register_button' => 'Cadastro',
		'register_limit' => 'Muitos cadstros - tente novamente em uma hora',
		'register_suspended' => 'Novos cadastros foram suspensos. Tente novamente mais tarde.',
		'register_title' => 'Novo cadastro',
		'registered_user' => 'Usuário registrado',
		'remember_label' => 'Lembrar de mim neste computador',
		'remember' => 'Lembrar',
		'remove_avatar' => 'Remover avatar:',
		'reset_code_another' => 'enviar outro',
		'reset_code_emailed' => 'O código foi enviado a seu email',
		'reset_code_label' => 'Código:',
		'reset_code_wrong' => 'Código incorreto',
		'reset_title' => 'Restaurar Senha Esquecida',
		'save_profile' => 'Salvar Perfil',
		'save_user' => 'Salvar Usuário',
		'send_confirm_button' => 'Enviar Link de Confirmação',
		'send_password_button' => 'Enviar Nova Senha',
		'send_reset_button' => 'Enviar Email de Restauração de Senha',
		'send_reset_note' => 'Uma mensagem será enviada a seu email com instruções.',
		'special_users' => 'Usuários especiais',
		'unblock_user_button' => 'Desbloquear Usuário',
		'unsubscribe_complete' => 'O seu email foi removido da lista de emails enviada por ^0. É possível reinserí-lo novamente na ^1página da sua conta^2.', 
		'unsubscribe_title' => 'Remover email da lista',
		'unsubscribe_wrong_log_in' => 'Código incorreto - ^1entre^2 para remover o email da lista',
		'unsubscribe' => 'Remover email da lista:',
		'user_blocked' => '(bloqueado)',
		'user_not_found' => 'Usuário não encontrado',
		'website' => 'Site',
		'x_ago_from_y' => '^1 atrás de ^2',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.6-language-pt-BR.zip: pt/qa-lang-users.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-users.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user management


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'about' => 'Sobre',
		'add_user_x_favorites' => 'Adicionar usuário ^ aos meus favoritos',
		'approve_required' => 'Aguarde a sua aprovação ou ^1atualize seus dados^2.',
		'approve_title' => 'Aprovação de usuário pendente',
		'approve_user_button' => 'Aprovar usuário',
		'approved_user' => 'Usuário aprovado',
		'avatar_default' => 'Padrão',
		'avatar_gravatar' => 'Mostrar meu ^1Gravatar^2',
		'avatar_label' => 'Avatar:',
		'avatar_none' => 'Nenhum',
		'block_user_button' => 'Bloquear usuário',
		'blocked_users' => 'Usuários bloqueados',
		'category_level_add' => ' - ^1adicionar privilégios de categoria^2',
		'category_level_in' => 'para a categoria abaixo:',
		'category_level_label' => 'Promovido para:',
		'category_level_none' => 'Sem promoção',
		'change_email_link' => ' - ^1mudar email^2',
		'change_password' => 'Alterar Senha',
		'confirm_complete' => 'Obrigado - Seu email foi confirmado',
		'confirm_emailed' => 'Um link de confirmação foi enviado a seu email. Clique nele para confirmá-lo.',
		'confirm_required' => 'Para completar o cadastro, clique no link de confirmação enviado a seu email ou ^1peça outro^2.',
		'confirm_title' => 'Confirmação de Email',
		'confirm_wrong_log_in' => 'Código Incorreto - ^1entre^2 para receber outro link',
		'confirm_wrong_resend' => 'Código Incorreto - clique abaixo para enviar novamente',
		'delete_user_button' => 'Excluir Usuário',
		'edit_user_button' => 'Editar Usuário',
		'email_confirmed' => 'Confirmado',
		'email_exists' => 'Email já pertence a outra conta',
		'email_handle_label' => 'Email or Nome:',
		'email_invalid' => 'Email é inválido - confira com cuidado',
		'email_label' => 'Email:',
		'email_not_confirmed' => 'Ainda não confirmado',
		'email_please_confirm' => '^5Confirme^6',
		'email_required' => 'Email necessário - não público',
		'forgot_link' => 'Esqueci minha senha',
		'full_name' => 'Nome completo',
		'handle_empty' => 'Nome não pode ficar vazio',
		'handle_exists' => 'Nome está em uso - tente outro',
		'handle_has_bad' => 'Nome não pode conter: ^',
		'handle_label' => 'Nome:',
		'hide_all_user_button' => 'Ocultar todas as publicações desse usuário',
		'last_login_label' => 'Última visita:',
		'last_write_label' => 'Última publicação:',
		'level_admin' => 'Administrador',
		'level_editor' => 'Editor',
		'level_expert' => 'Expert',
		'level_for_category' => '^1 para ^2',
		'level_in_general' => 'em geral',
		'level_moderator' => 'Moderador',
		'level_super' => 'Super Administrador',
		'location' => 'Localização',
		'log_in_to_access' => 'Você pode ^1acessar^2 a sua conta.',
		'login_button' => 'Login',
		'login_limit' => 'Muitas tentativas de login - tente novamente em uma hora',
		'login_title' => 'Login',
		'mass_mailings_explanation' => 'Inscreva-se nos email enviados a todos os usuários',
		'mass_mailings' => 'Emails em massa:',
		'member_for' => 'Usuário por:',
		'member_type' => 'Tipo:',
		'new_password_1' => 'Nova senha:',
		'new_password_2' => 'Redigite a nova senha:',
		'no_blocked_users' => 'Nenhum usuário bloqueado encontrado',
		'no_permission' => 'Você não permissão para executar essa operação',
		'old_password' => 'Senha antiga:',
		'only_shown_admins' => '(somente mostrado a administradores)',
		'only_shown_editors' => '(somente mostrado para editores e superiores)',
		'only_shown_experts' => '(somente mostrado para experts e superiores)',
		'only_shown_moderators' => '(somente mostrado a moderadores e superiores)',
		'password_changed' => 'Senha alterada',
		'password_label' => 'Senha:',
		'password_min' => 'Senha deve ter ao menos ^ caracteres',
		'password_mismatch' => 'As senhas não conferem',
		'password_none' => 'Nenhum. Para fazer login diretamente, escolha uma senha abaixo.',
		'password_sent' => 'Sua nova senha foi enviada a seu email',
		'password_to_set' => 'Defina na página da sua conta',
		'password_wrong' => 'Senha incorreta',
		'private_messages_explanation' => 'Permitir que usuários me enviem emails (sem mostrar meu email)',
		'private_messages' => 'Mensagens privadas:',
		'profile_saved' => 'Perfil salvo',
		'wall_posts' => 'Publicações do mural:',
		'wall_posts_explanation' => 'Permitir publicações em seu mural (você também receberá por e-mail)',
		'register_button' => 'Cadastro',
		'register_limit' => 'Muitos cadstros - tente novamente em uma hora',
		'register_suspended' => 'Novos cadastros foram suspensos. Tente novamente mais tarde.',
		'register_title' => 'Novo cadastro',
		'registered_label' => 'Cadastrado:',
		'registered_user' => 'Usuário cadastrado',
		'remember_label' => 'Lembrar de mim neste computador',
		'remember' => 'Lembrar',
		'remove_avatar' => 'Remover avatar:',
		'reset_code_another' => 'enviar outro',
		'reset_code_emailed' => 'O código foi enviado a seu email',
		'reset_code_label' => 'Código:',
		'reset_code_wrong' => 'Código incorreto',
		'reset_title' => 'Restaurar Senha Esquecida',
		'save_profile' => 'Salvar Perfil',
		'save_user' => 'Salvar Usuário',
		'send_confirm_button' => 'Enviar Link de Confirmação',
		'send_password_button' => 'Enviar Nova Senha',
		'send_reset_button' => 'Enviar Email de Restauração de Senha',
		'send_reset_note' => 'Uma mensagem será enviada a seu email com instruções.',
		'special_users' => 'Usuários especiais',
		'unblock_user_button' => 'Desbloquear Usuário',
		'unsubscribe_complete' => 'O seu email foi removido da lista de emails enviada por ^0. É possível reinserí-lo novamente na ^1página da sua conta^2.', 
		'unsubscribe_title' => 'Remover email da lista',
		'unsubscribe_wrong_log_in' => 'Código incorreto - ^1entre^2 para remover o email da lista',
		'unsubscribe' => 'Remover email da lista:',
		'user_blocked' => '(bloqueado)',
		'user_not_found' => 'Usuário não encontrado',
		'website' => 'Site',
		'x_ago_from_y' => '^1 atrás de ^2',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
